[Classes](classifiers.html) in this package are mappings of the [architecture model](../../../index.html) classes to the abstractions of the [The C4 model for visualising software architecture](https://c4model.com/).

The classes in this package do not introduce any new structural features (attributes or references) or operations, just new semantics.
E.g. [System](references/eClassifiers/System/index.html) and [Container](references/eClassifiers/Container/index.html) extend [CompositeNode](../../eClassifiers/CompositeNode/index.html) -
they can have documentation, icon, incoming and outgoing connections, nested elements, ... 
The difference between them is in definitions.

## Demos

### Internet Banking System

* Generated documentation sites with different [Bootswatch](https://bootswatch.com/4/) themes: 
    * [Cerulean](/demo/internet-banking-system-c4/cerulean/index.html) - can be used to publish the base line architecture - what is already deployed.
    * [Sketchy](/demo/internet-banking-system-c4/sketchy/index.html) - can be used to publish future architectures.
* [Source code](https://github.com/Nasdanika-Models/architecture/tree/main/demos/internet-banking-system-c4)    

#### Direct Generation

There is also a demo of documentation produced with "[Direct Generation](https://github.com/Nasdanika-Templates/drawio-site)" approach explained in [Visual communication continuum](https://medium.com/nasdanika/visual-communication-continuum-4946f44ba853) story (also in Resources):

* [Site](https://nasdanika-demos.github.io/internet-banking-system/)
* [Sources](https://github.com/Nasdanika-Demos/internet-banking-system)

The direct generation approach is simpler and might be easier to get started with. It was designed to be compatible with semantic mapping explained here to simplify migration.

### Basic demo

* Generated documentation sites with different [Bootswatch](https://bootswatch.com/4/) themes: 
    * [Cerulean](/demo/c4/cerulean/index.html)
    * [Sketchy](/demo/c4/sketchy/index.html)
* [Source code](https://github.com/Nasdanika-Models/architecture/tree/main/demos/c4)    

## Quick Start

<div class="embed-responsive embed-responsive-16by9">
  <iframe src="https://www.youtube.com/embed/LNdGYB5fxgM?si=TASIJM5jGx6UYgq-" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>
</div>


* Start Drawio editor - [in-browser](https://app.diagrams.net/), [desktop](https://github.com/jgraph/drawio-desktop/releases) (also [drawio.io Diagrams in Microsoft Store](https://apps.microsoft.com/detail/9mvvszk43qqw?hl=en-US&gl=US)), or [VS Code extension](https://marketplace.visualstudio.com/items?itemName=hediet.vscode-drawio). 
* Create a new diagram from https://architecture.models.nasdanika.org/resources/c4-template.drawio template
* Add https://architecture.models.nasdanika.org/resources/C4.xml library
* Add elements from the C4 library above to the diagram. You may edit elements id's or add ``semantic-id`` property to have meaningful (semantic) URL's in generated documentation and meaningful identifiers for cross-referencing.
* Create additional diagram pages for diagram elements with internal structures. E.g. a [System](/references/eSubpackages/c4/references/eClassifiers/System/index.html) consisting of [Containers](/references/eSubpackages/c4/references/eClassifiers/Container/index.html). Link the diagram elements to their respective pages. There can be multiple levels of diagram hierarchy. 
* Add ``Context`` container from the C4 library to a sub-diargram page.
* Add children of the diagram element to the context container. E.g. containers to a system context container.
* Add diagram elements to link already defined elements. E.g. a [Person](/references/eSubpackages/c4/references/eClassifiers/Person/index.html). Remove ``type`` property and add ``selector`` property to link the diagram element to an already defined mapping of a diagram element to a semantic element. For example, ``getDocument().getModelElementById('user')`` would link a diagram element to another diagram element with id ``user``. ``getDocument().getModelElementByProperty('semantic-id', 'personal-banking-customer')`` selects an element by its property value. It is also possible to do page-level selections: ``getDocument().getPageByXXX().getModelElementByXXX()``.
* Save the diagram.
* Use [Nasdanika CLI](https://docs.nasdanika.org/nsd-cli/index.html) [app/model/site](https://docs.nasdanika.org/nsd-cli/nsd/app/model/site/index.html) command
or [app/model/action](https://docs.nasdanika.org/nsd-cli/nsd/app/model/action/index.html) command and then [app/site](https://docs.nasdanika.org/nsd-cli/nsd/app/site/index.html) command to generate documentation site.


### Linking relationships

Relationships documentation can be accessed by clicking relationships on diagrams in generated documentation. 
To link relationships from Markdown use ``references/outgoingConnections/<id>/index.html`` URL relative to the relationship source. ``<id>`` stands for the semantic id, which defaults to the diagram element id if not set via ``semantic-id`` property.  

### Sample command

```
nsd app model site -f C:\_temp\c4\c4.drawio C:\_temp\c4\site --root-action-text="Nasdanika C4 Model Demos"
```

## Resources

* [Visual communication continuum](https://medium.com/nasdanika/visual-communication-continuum-4946f44ba853) story introduces "[Direct Generation](https://github.com/Nasdanika-Templates/drawio-site)" of documentation from diagrams, which is simpler than semantic mapping. I also compares direct generation with semantic mapping.
* [Architecture As Code](https://medium.com/nasdanika/architecture-as-code-7c0eadfc0b2b) story explains high level concepts and possible applications of the architecture model. 
* [Beyond Diagrams](https://leanpub.com/beyond-diagrams) book provides a detailed explanation how to map [Drawio](https://www.drawio.com/) diagrams to semantic models, make them executable, ... The book is still work in progress, more installments to come!
* [Reference documentation](https://docs.nasdanika.org/index.html)